Module entity

Module entity 

Structs

EntityDescs
Descriptions for entities (nodes, edges, and edge groups).
EntityTypeId
Unique identifier for an entity type in the diagram, Id newtype.
EntityTypes
Entity types attached to things, edges, processes, process steps and tags for common styling.