Structs
- Entity
Descs - Descriptions for entities (nodes, edges, and edge groups).
- Entity
Type Id - Unique identifier for an entity type in the diagram,
Idnewtype. - Entity
Types - Entity types attached to things, edges, processes, process steps and tags for common styling.